; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------
[Command]
name = "Shory_x"
command = ~F, D, DF, x

[Command]
name = "Shory_y"
command = ~F, D, DF, y

[Command]
name = "Leigan_x"
command = ~D, DF, F, x

[Command]
name = "Leigan_y"
command = ~D, DF, F, y

[Command]
name = "YusukeKnee_a"
command = ~F, DF, F, a

[Command]
name = "YusukeKnee_b"
command = ~F, DF, F, b

[Command]
name = "ShotGun_X"
command = ~F, B, F, x

[Command]
name = "ShotGun_Y"
command = ~F, B, F, y


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "teste"
command = a+b

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "SuperPulo"
command = $D, U

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Shory_X
[State -1]
type = ChangeState
value = 1100
triggerall = command = "Shory_x"
trigger1 = statetype != A
trigger1 = ctrl

;Shory_Y
[State -1]
type = ChangeState
value = 1200
triggerall = command = "Shory_y"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Leigan_X
[State -1]
type = ChangeState
value = 1000
triggerall = command = "Leigan_x"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;Leigan_Y
[State -1]
type = ChangeState
value = 1050
triggerall = command = "Leigan_y"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;ShotGun_X
[State -1]
type = ChangeState
value = 1300
triggerall = command = "ShotGun_X"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 1000
trigger2 = movecontact = 1

;ShotGun_Y
[State -1]
type = ChangeState
value = 1400
triggerall = command = "ShotGun_Y"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 1000
trigger2 = movecontact = 1

;=========================================================
;Soco Fraco em P
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1= statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1

;Soco Fraco Abaixado
[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1
trigger8 = stateno = 200
trigger8 = movecontact = 1
trigger9 = stateno = 210
trigger9 = movecontact = 1


;Arremesso
[State -1]
type = ChangeState
value = 801
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;Soco Forte em P
[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1

;Soco Forte Abaixado
[State -1]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 200
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;Chute Fraco em P
[State -1]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1

;Chute Fraco Abaixado
[State -1]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1

;Chute Forte em P
[State -1]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1

;Chute Forte Abaixado
[State -1]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 240   
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 430
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
;-----------------------------------------------
;Soco Fraco no Ar
[State -1]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1= statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630
trigger2 = movecontact = 1
trigger3 = stateno = 640   
trigger3 = movecontact = 1
trigger4 = stateno = 600
trigger4 = movecontact = 1
trigger5 = stateno = 610
trigger5 = movecontact = 1

;Soco Forte no Ar
[State -1]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630
trigger2 = movecontact = 1
trigger3 = stateno = 640   
trigger3 = movecontact = 1
trigger4 = stateno = 600
trigger4 = movecontact = 1
trigger5 = stateno = 610
trigger5 = movecontact = 1

;Chute Fraco no Ar
[State -1]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630
trigger2 = movecontact = 1
trigger3 = stateno = 640   
trigger3 = movecontact = 1
trigger4 = stateno = 600
trigger4 = movecontact = 1
trigger5 = stateno = 610
trigger5 = movecontact = 1

;Chute Forte no Ar
[State -1]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630
trigger2 = movecontact = 1
trigger3 = stateno = 640   
trigger3 = movecontact = 1
trigger4 = stateno = 600
trigger4 = movecontact = 1
trigger5 = stateno = 610
trigger5 = movecontact = 1

;Dash p/ Frente
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Dash p/ Trs
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Super Pulo
[State -1]
type = ChangeState
value = 5400
triggerall = command = "SuperPulo"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Provocao (Taunt)
[State -1]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype = S
trigger1 = ctrl = 1


